#mortgageGUI.py
# Copyright 2010 Joshua Grigonis
# This file is written by Joshua Grigonis.  Redistribution or reuse is not permitted without 
# express written consent.
# contact: josh.grigonis@gmail.com
#

from Tkinter import *
import tkMessageBox
import mortgage
import mortgageExceptions

#==================================================================================================================================================================================

GUIversion = 0.4

#==================================================================================================================================================================================
class App:
#----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------		
	def __init__(self, master):


		
    	
		self.principalLabel = Label (master, text = "Principal").grid (row = 0, sticky = W, padx = 10)
		self.principalEntry = Entry (master)
		self.principalEntry.grid (row = 0, column = 1)
		self.principalButton = Button (master, text = "Calculate", command = self.calculatePrincipalButtonPressed).grid (row = 0, column = 2, padx = 10)

		self.paymentLabel = Label (master, text = "Monthly Payment").grid (row = 1, sticky = W, padx = 10)
		self.paymentEntry = Entry (master)
		self.paymentEntry.grid (row = 1, column = 1)
		self.paymentButton = Button (master, text = "Calculate", command = self.calculatePaymentButtonPressed).grid (row = 1, column = 2, padx = 10)

		self.numberOfPaymentsLabel = Label (master, text = "Number of payments").grid (row = 2, sticky = W, padx = 10)
		self.numberOfPaymentsEntry = Entry (master)
		self.numberOfPaymentsEntry.grid (row = 2, column = 1)
		self.numberOfPaymentsButton = Button (master, text = "Calculate", command = self.calculateNumberOfPaymentsButtonPressed).grid (row = 2, column = 2, padx = 10)

		self.interestRateLabel = Label (master, text = "Interest rate").grid (row = 3, sticky = W, padx = 10)
		self.interestRateEntry = Entry (master)
		self.interestRateEntry.grid (row = 3, column = 1)
		self.interestRateButton = Button (master, text = "Calculate", command = self.calculateInterestRateButtonPressed).grid (row = 3, column = 2, padx = 10)
		
		self.clearAllButton = Button (master, text = "Clear All", command = self.clearAll).grid (row = 4, column = 1)
		
		self.aboutButton = Button (master, text = "About", command = self.displayAboutBox).grid (row = 4, column = 2, padx = 10, pady = 10)
		
		
		#Label (image = PhotoImage(file = "liger-2.gif")).grid (row = 5, column = 0)
		
#----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------		
	# Display Versions and information
	def displayAboutBox (self):
		
		tkMessageBox.showinfo ("About Mortgage Calculator", 
				"A Mortgage Calculator\nWritten by Joshua Grigonis\nemail: josh.grigonis@gmail.com\n\nMortgage GUI Version: %s\nMortgage Class Version: %s\n" % (GUIversion, mortgage.Mortgage.version))	
#----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------		
	# Clear all the mortgage data entry fields.
	# reset m to a new Mortgage
	def clearAll (self):
		# Clear all Entry fields
		
		self.principalEntry.delete(0, END)
		self.paymentEntry.delete(0, END)
		self.numberOfPaymentsEntry.delete(0, END)
		self.interestRateEntry.delete(0, END)
		self.m = mortgage.Mortgage ()
	
#----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------		
	def calculatePrincipalButtonPressed (self):
		try:
			m = mortgage.Mortgage (payment = self.paymentEntry.get(), numberOfPayments = self.numberOfPaymentsEntry.get(), interestRate = self.interestRateEntry.get())
		except:
			# Beep
			root.bell()
			return
		try:
			principal = m.calculatePrincipal ()
		except mortgageExceptions.UnsetVariableError:
			root.bell()
			return
		except:
			raise
		
		self.principalEntry.delete(0, END)
		self.principalEntry.insert(INSERT, round(principal, 2))
#----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------			
	def calculatePaymentButtonPressed (self):
		try:
			m = mortgage.Mortgage (principal = self.principalEntry.get(), numberOfPayments = self.numberOfPaymentsEntry.get(), interestRate = self.interestRateEntry.get())
		except:
			# Beep
			root.bell()
			return
		try:
			payment = m.calculatePayment ()
		except mortgageExceptions.UnsetVariableError:
			root.bell()
			return
		except:
			raise
		
		self.paymentEntry.delete(0, END)
		self.paymentEntry.insert(INSERT, round(payment, 2))
#----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------				
	def calculateNumberOfPaymentsButtonPressed (self):
		try:
			m = mortgage.Mortgage (principal = self.principalEntry.get(), payment = self.paymentEntry.get(), interestRate = self.interestRateEntry.get())
		except:
			# Beep
			root.bell()
			return
		try:
			numberOfPayments = m.calculateNumberOfPayments ()
		except mortgageExceptions.PaymentTooLowError:
			root.bell()
			tkMessageBox.showwarning ("Payment Too Low Error", 
				"The payment is too low, or the principal and interest is too high.\n\nRaise the payments or lower the principal and/or interest.")
			return
		except mortgageExceptions.UnsetVariableError:
			root.bell()
			return
		except:
			raise
		
		self.numberOfPaymentsEntry.delete(0, END)
		self.numberOfPaymentsEntry.insert(INSERT, round(numberOfPayments, 2))
#----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------		
	def calculateInterestRateButtonPressed (self):
		try:
			m = mortgage.Mortgage (principal = self.principalEntry.get(), numberOfPayments = self.numberOfPaymentsEntry.get(), payment = self.paymentEntry.get())
		except:
			# Beep
			root.bell()
			return
		try:
			interestRate = m.calculateInterestRate ()
		except mortgageExceptions.PaymentTooLowError:
			root.bell()
			tkMessageBox.showwarning ("Payment Too Low Error", 
				"The payment, or the number of them is too low.\n\nRaise the payments, or number of payments, or lower the principal")
			return
		except mortgageExceptions.UnsetVariableError:
			root.bell()
			return
		except:
			raise
		
		self.interestRateEntry.delete(0, END)
		self.interestRateEntry.insert(INSERT, round(interestRate, 2))
		

#==================================================================================================================================================================================
		
root = Tk ()
root.title ('Mortgage Calculator')

app = App (root)

root.mainloop ()